<?php

namespace App\Http\Controllers\Admin;

use Datatables;
use Carbon\Carbon;
use App\Models\Product;
use App\Models\Currency;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Support\Facades\Validator;

class InventoryController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:admin');
    }

    //*** JSON Request
    public function datatables()
    {
        $datas = Product::where('product_type', '=', 'normal')->orderBy('id', 'desc')->get();
        //--- Integrating This Collection Into Datatables
        return Datatables::of($datas)
            ->editColumn('product_name', function (Product $data) {
                $name =  mb_strlen($data->name, 'UTF-8') > 50 ? mb_substr($data->name, 0, 50, 'UTF-8') . '...' : $data->name;
                return  $name;
            })
            ->editColumn('date', function (Product $data) {
                return  date('Y/m/d', strtotime(($data->updated_at == null || $data->updated_at == "") ? $data->created_at : $data->updated_at));
            })
            ->editColumn('supplier', function (Product $data) {
                $user_name = "";
                try {
                    $user_name = User::select("name")->where("id", "=", $data->user_id)->first();
                    $user_name = $user_name->name;
                } catch (\Exception $e) {
                };
                return  $user_name;
            })
            ->editColumn('code', function (Product $data) {
                return  $data->sku;
            })
            ->editColumn('net_unity_cost', function (Product $data) {
                $sign = Currency::where('is_default', '=', 1)->first();
                $price = round($data->previous_price * $sign->value, 2);
                $price = $sign->sign . $price;
                return  $price;
            })
            ->editColumn('discound_recived', function (Product $data) {
                $sign = Currency::where('is_default', '=', 1)->first();
                $price = round($data->price * $sign->value, 2);
                $price = $sign->sign . $price;
                return  $price;
            })
            ->editColumn('quantity', function (Product $data) {
                $stck = (string)$data->stock;
                if ($stck == "0")
                    return "Out Of Stock";
                elseif ($stck == null)
                    return "Unlimited";
                else
                    return $data->stock;
            })
            ->editColumn('batch_no', function (Product $data) {
                $stck = (string)$data->batch_no;
                if ($stck == "1")
                    return "First Batch";
                else if ($stck == null || $stck == "")
                    return "Not definded";
                else
                    return $data->batch_no;
            })
            ->editColumn('expiry_date', function (Product $data) {
                return ($data->expairy_date == null && $data->expairy_date == "") ? "Unlimited" : date('Y/m/d', strtotime($data->expairy_date));
            })

            ->addColumn('notes', function (Product $data) {
                return ($data->product_notes != "" || $data->product_notes != null) ? $data->product_notes : "No notes available";
            })
            ->addColumn('action', function (Product $data) {
                return '<div class="action-list"><a onclick="inventory_edit(' . $data->id . ')"> <i class="fas fa-edit"></i> Edit</a></div>';
            })
            ->rawColumns(['product_name', 'action'])
            ->toJson(); //--- Returning Json Data To Client Side
    }

    //*** GET Request
    public function index()
    {
        return view('admin.Inventory.index');
    }

    // stock update
    public function update_stock(Request $request)
    {
        // validation
        $validator = Validator::make($request->all(), [
            "product_id" => "required",
            "product_owner_name" => "required",
            "product_name" => "required",
            "product_code" => "required",
            "product_net_cost" => "required",
            "product_quantity" => "required",
            "product_discount_price" => "required",
            "product_notes" => "required",
        ]);

        if ($validator->fails()) {
            $return['msg'] = $validator->messages()->first();
            $return['status'] = 400;
            return response($return, 400);
        }

        //  default values
        $product_id = $request->product_id;
        $product_owner_name = $request->product_owner_name;
        $product_name = $request->product_name;
        $product_code = $request->product_code;
        $product_expiry_date = $request->product_expiry_date;
        $product_net_cost = $request->product_net_cost;
        $product_stock = $request->product_quantity;
        $product_discount_price = $request->product_discount_price;
        $product_notes = $request->product_notes;
        $product_batch_no = $request->product_batch_no;
        $product_batch = Product::select("batch_no",'stock')->findOrFail($product_id);
        $datas['product_response'] = Product::where('id', '=', $product_id)->update([
            "product_notes" => $product_notes,
            "sku" => $product_code,
            "name" => $product_name,
            "price" => $product_discount_price,
            "previous_price" => $product_net_cost,
            "stock" => $product_batch->stock + $product_stock,
            "batch_no" => $product_batch->batch_no != null ? $product_batch->batch_no + 1 : 1,
            "expairy_date" => $product_expiry_date ? $product_expiry_date : null
        ]);
        $datas['status'] = 200;
        return response($datas, 200);
    }

    public function edit_inventory_data(Request $request)
    {
        $product_id = $request->product_id;
        if ($product_id == "") {
            $datas['product_response'] = null;
            $datas['status'] = 200;
            return response($datas, 200);
        }
        $datas['product_response'] = Product::select("products.id", "sku", "users.name as UserName", "products.name", "product_type", "price", "previous_price", "stock", "expairy_date", "product_notes")->join("users", "products.user_id", "=", "users.id")->findOrFail($product_id);
        $datas['status'] = 200;
        return response($datas, 200);
    }
}
