<?php

namespace App\Http\Controllers\User;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\Generalsetting;
use App\Models\User;
use App\Classes\GeniusMailer;
use App\Models\Notification;
use App\Http\Services\DealerServices;
use Auth;

use Illuminate\Support\Facades\Validator;
use PhpParser\Node\Expr\FuncCall;

class RegisterController extends Controller
{

	public function register(Request $request)
	{

		$gs = Generalsetting::findOrFail(1);

		if ($gs->is_capcha == 1) {
			$value = session('captcha_string');
			if ($request->codes != $value) {
				return response()->json(array('errors' => [0 => 'Please enter Correct Capcha Code.']));
			}
		}


		//--- Validation Section

		$rules = [
			'email'   => 'required|email|unique:users',
			'password' => 'required|confirmed'
		];
		$validator = Validator::make($request->all(), $rules);

		if ($validator->fails()) {
			return response()->json(array('errors' => $validator->getMessageBag()->toArray()));
		}
		//--- Validation Section Ends

		$user = new User;
		$input = $request->all();
		$input['password'] = bcrypt($request['password']);
		$token = md5(time() . $request->name . $request->email);
		$input['verification_link'] = $token;
		$input['affilate_code'] = md5($request->name . $request->email);

		if (!empty($request->vendor)) {
			//--- Validation Section
			$rules = [
				'shop_name' => 'unique:users',
				'shop_number'  => 'max:10'
			];
			$customs = [
				'shop_name.unique' => 'This Shop Name has already been taken.',
				'shop_number.max'  => 'Shop Number Must Be Less Then 10 Digit.'
			];

			$validator = Validator::make($request->all(), $rules, $customs);
			if ($validator->fails()) {
				return response()->json(array('errors' => $validator->getMessageBag()->toArray()));
			}
			$input['is_vendor'] = 1;
		}

		$user->fill($input)->save();
		if ($gs->is_verification_email == 1) {
			$to = $request->email;
			$subject = 'Verify your email address.';
			$msg = "Dear Customer,<br> We noticed that you need to verify your email address. <a href=" . url('user/register/verify/' . $token) . ">Simply click here to verify. </a>";
			//Sending Email To Customer
			if ($gs->is_smtp == 1) {
				$data = [
					'to' => $to,
					'subject' => $subject,
					'body' => $msg,
				];

				$mailer = new GeniusMailer();
				$mailer->sendCustomMail($data);
			} else {
				$headers = "From: " . $gs->from_name . "<" . $gs->from_email . ">";
				mail($to, $subject, $msg, $headers);
			}
			return response()->json('We need to verify your email address. We have sent an email to ' . $to . ' to verify your email address. Please click link in that email to continue.');
		} else {

			$user->email_verified = 'Yes';
			$user->update();
			$notification = new Notification;
			$notification->user_id = $user->id;
			$notification->save();
			Auth::guard('web')->login($user);
			return response()->json(1);
		}
	}

	public function token($token)
	{
		$gs = Generalsetting::findOrFail(1);

		if ($gs->is_verification_email == 1) {
			$user = User::where('verification_link', '=', $token)->first();
			if (isset($user)) {
				$user->email_verified = 'Yes';
				$user->update();
				$notification = new Notification;
				$notification->user_id = $user->id;
				$notification->save();
				Auth::guard('web')->login($user);
				return redirect()->route('user-dashboard')->with('success', 'Email Verified Successfully');
			}
		} else {
			return redirect()->back();
		}
	}

	public function showDealerForm(){
		return view('dealer.dealer_login');
	}

	public function registerDealer(Request $request)
	{
		$validator = Validator::make($request->all(), [
			'dealerName' => 'required|string',
			'address' => 'required|string',
			'city' => 'required|string',
			'postalcode' => 'required|string',
			'country' => 'required|string',
			'phone' => 'required|integer',
			'fax' => 'required|string',
			'email' => 'required|email',
			'website' => 'required|string',
			'principal_contact_and_title' => 'required|string',
			'purchase_contact' => 'required|integer',
			'company_name1' => 'string|nullable',
			'company_address1' => 'string|nullable',
			'company_mob1' => 'integer|nullable',
			'company_web1' => 'string|nullable',
			'company_name2' => 'string|nullable',
			'company_address2' => 'string|nullable',
			'company_mob2' => 'integer|nullable',
			'company_web2' => 'string|nullable',
			'company_name3' => 'string|nullable',
			'company_address3' => 'string|nullable',
			'company_mob3' => 'integer|nullable',
			'bank_info' => 'required|string',
			'bank_name' => 'required|string',
			'bank_branch' => 'required|string',
			'bank_acc_no' => 'required|integer',
		]);
		if ($validator->fails()) {
			if ($request->codes != "") {
				return response()->json(array('errors' => $validator->getMessageBag()->toArray()));
			}
			return back()->withErrors($validator);
		}
		try {
			$dealer_name = $request->dealerName;
			$dealer_email = $request->email;
			$response = DealerServices::inserDealers($request->all());
			// return response()->json(["status" => "200", 'msg' => "Registered Successfully"]);
			$gs = Generalsetting::findOrFail(1);
			$subject = "New Dealer Registerd";
			$msg = '<!DOCTYPE html><html lang="en"><head><meta charset="utf-8"><meta name="viewport" content="width=device-width, initial-scale=1"><link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.4.1/css/bootstrap.min.css"><script src="https://ajax.googleapis.com/ajax/libs/jquery/3.6.0/jquery.min.js"></script><script src="https://maxcdn.bootstrapcdn.com/bootstrap/3.4.1/js/bootstrap.min.js"></script></head><body><div class="container"><h2>Dealer Registration</h2>
		  <table class="table"><thead><tr><th>Dealer Name</th><th>Dealer Email</th></tr></thead><tbody><tr><td>' . $dealer_name . '</td><td>' . $dealer_email . '</td></tr></tbody></table><h1>Thank You</h1></div>
		</body></html>';
			if ($gs->is_smtp == 1) {
				$data_delaer = [
					'to' => $dealer_email,
					'subject' => $subject,
					'body' => $msg,
				];
				$data_admin = [
					'to' => 'dealer@aladil.co.th',
					'subject' => $subject,
					'body' => $msg,
				];
				$mailer = new GeniusMailer();
				$mailer->sendCustomMail($data_admin); //admin
				$mailer->sendCustomMail($data_delaer); //dealer

			} else {
				$headers_admin = "From: " . $dealer_name . "<" . $dealer_email . ">";
				$headers_user = "From: " . $gs->from_name . "<" . $gs->from_email . ">";
				mail('dealer@aladil.co.th', $subject, $msg, $headers_admin); //admin
				mail($request->email, $subject, $msg, $headers_user); //user
			}
			if ($response >= 1) {
				if ($request->codes != "") {
					return response()->json(["status" => "200", 'msg' => "Registered Successfully"]);
				}
				return redirect('/')->with('success_dealer', 'Dealer register successfully');
			}
		} catch (\Exception $e) {
			return response()->json(array('errors' => 'registration fails'));
		}
	}
}
